#[doc = "Register `EMAC_25M_CLK` reader"]
pub struct R(crate::R<EMAC_25M_CLK_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<EMAC_25M_CLK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<EMAC_25M_CLK_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<EMAC_25M_CLK_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `EMAC_25M_CLK` writer"]
pub struct W(crate::W<EMAC_25M_CLK_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<EMAC_25M_CLK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<EMAC_25M_CLK_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<EMAC_25M_CLK_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Gating Special Clock\n\nValue on reset: 0"]
#[derive(Clone, Copy, Debug, PartialEq)]
pub enum CLK_GATING_A {
    #[doc = "0: `0`"]
    OFF = 0,
    #[doc = "1: `1`"]
    ON = 1,
}
impl From<CLK_GATING_A> for bool {
    #[inline(always)]
    fn from(variant: CLK_GATING_A) -> Self {
        variant as u8 != 0
    }
}
#[doc = "Field `CLK_GATING` reader - Gating Special Clock"]
pub type CLK_GATING_R = crate::BitReader<CLK_GATING_A>;
impl CLK_GATING_R {
    #[doc = "Get enumerated values variant"]
    #[inline(always)]
    pub fn variant(&self) -> CLK_GATING_A {
        match self.bits {
            false => CLK_GATING_A::OFF,
            true => CLK_GATING_A::ON,
        }
    }
    #[doc = "Checks if the value of the field is `OFF`"]
    #[inline(always)]
    pub fn is_off(&self) -> bool {
        *self == CLK_GATING_A::OFF
    }
    #[doc = "Checks if the value of the field is `ON`"]
    #[inline(always)]
    pub fn is_on(&self) -> bool {
        *self == CLK_GATING_A::ON
    }
}
#[doc = "Field `CLK_GATING` writer - Gating Special Clock"]
pub type CLK_GATING_W<'a> = crate::BitWriter<'a, u32, EMAC_25M_CLK_SPEC, CLK_GATING_A, 31>;
impl<'a> CLK_GATING_W<'a> {
    #[doc = "`0`"]
    #[inline(always)]
    pub fn off(self) -> &'a mut W {
        self.variant(CLK_GATING_A::OFF)
    }
    #[doc = "`1`"]
    #[inline(always)]
    pub fn on(self) -> &'a mut W {
        self.variant(CLK_GATING_A::ON)
    }
}
#[doc = "Gating the Source Clock of Special Clock\n\nValue on reset: 0"]
#[derive(Clone, Copy, Debug, PartialEq)]
pub enum CLK_SRC_GATING_A {
    #[doc = "0: `0`"]
    OFF = 0,
    #[doc = "1: `1`"]
    ON = 1,
}
impl From<CLK_SRC_GATING_A> for bool {
    #[inline(always)]
    fn from(variant: CLK_SRC_GATING_A) -> Self {
        variant as u8 != 0
    }
}
#[doc = "Field `CLK_SRC_GATING` reader - Gating the Source Clock of Special Clock"]
pub type CLK_SRC_GATING_R = crate::BitReader<CLK_SRC_GATING_A>;
impl CLK_SRC_GATING_R {
    #[doc = "Get enumerated values variant"]
    #[inline(always)]
    pub fn variant(&self) -> CLK_SRC_GATING_A {
        match self.bits {
            false => CLK_SRC_GATING_A::OFF,
            true => CLK_SRC_GATING_A::ON,
        }
    }
    #[doc = "Checks if the value of the field is `OFF`"]
    #[inline(always)]
    pub fn is_off(&self) -> bool {
        *self == CLK_SRC_GATING_A::OFF
    }
    #[doc = "Checks if the value of the field is `ON`"]
    #[inline(always)]
    pub fn is_on(&self) -> bool {
        *self == CLK_SRC_GATING_A::ON
    }
}
#[doc = "Field `CLK_SRC_GATING` writer - Gating the Source Clock of Special Clock"]
pub type CLK_SRC_GATING_W<'a> = crate::BitWriter<'a, u32, EMAC_25M_CLK_SPEC, CLK_SRC_GATING_A, 31>;
impl<'a> CLK_SRC_GATING_W<'a> {
    #[doc = "`0`"]
    #[inline(always)]
    pub fn off(self) -> &'a mut W {
        self.variant(CLK_SRC_GATING_A::OFF)
    }
    #[doc = "`1`"]
    #[inline(always)]
    pub fn on(self) -> &'a mut W {
        self.variant(CLK_SRC_GATING_A::ON)
    }
}
impl R {
    #[doc = "Bit 31 - Gating Special Clock"]
    #[inline(always)]
    pub fn clk_gating(&self) -> CLK_GATING_R {
        CLK_GATING_R::new(((self.bits >> 31) & 1) != 0)
    }
    #[doc = "Bit 31 - Gating the Source Clock of Special Clock"]
    #[inline(always)]
    pub fn clk_src_gating(&self) -> CLK_SRC_GATING_R {
        CLK_SRC_GATING_R::new(((self.bits >> 31) & 1) != 0)
    }
}
impl W {
    #[doc = "Bit 31 - Gating Special Clock"]
    #[inline(always)]
    pub fn clk_gating(&mut self) -> CLK_GATING_W {
        CLK_GATING_W::new(self)
    }
    #[doc = "Bit 31 - Gating the Source Clock of Special Clock"]
    #[inline(always)]
    pub fn clk_src_gating(&mut self) -> CLK_SRC_GATING_W {
        CLK_SRC_GATING_W::new(self)
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "EMAC_25M Clock Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [emac_25m_clk](index.html) module"]
pub struct EMAC_25M_CLK_SPEC;
impl crate::RegisterSpec for EMAC_25M_CLK_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [emac_25m_clk::R](R) reader structure"]
impl crate::Readable for EMAC_25M_CLK_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [emac_25m_clk::W](W) writer structure"]
impl crate::Writable for EMAC_25M_CLK_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets EMAC_25M_CLK to value 0"]
impl crate::Resettable for EMAC_25M_CLK_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
